# Boostrap alerts extension for Python-Markdown

This extension adds bootstrap alerts support to [Python-Markdown].

[Python-Markdown]: https://github.com/Python-Markdown/markdown


## Installation

### Install from PyPI

```
$ python -m pip install python-markdown-bootstrap-alerts
```

### Install locally

Use `setup.py build` and `setup.py install` to build and install this
extension, respectively.

The extension name is `mdx_alerts`, so you need to add that name to your
list of Python-Markdown extensions.
Check [Python-Markdown documentation] for details on how to load
extensions.

[Python-Markdown documentation]: https://python-markdown.github.io/reference/#extensions


## Usage

